import requests
import json

class ApiClient:
    def __init__(self, base_url="http://213.239.225.119", token=None):
        self.base_url = base_url
        self.token = token

    def login(self, username, password):
        headers = {
                    'accept': 'application/json',
                    'Content-Type': 'application/x-www-form-urlencoded'
                   }
        login_url = f"{self.base_url}:81/api/auth/login"
        data = f'username={username}&password={password}'
        response = requests.post(login_url, data=data,headers=headers)
        if response.status_code == 200:
            if response.json().get("error_code") == 0:
                self.token = response.json().get('data').get('access_token')
                return self.token
            
        raise ValueError("نام کاربری یا رمز عبور اشتباه است")

    def chat(self, bot_id,message):
        if not self.token:
            raise ValueError("لطفا ابتدا لاگین کنید")
        
        chat_url = f"{self.base_url}:5001/api/bot/{bot_id}/chat"
        headers = {'Authorization': f"Bearer {self.token}"}
        data = json.dumps({'data': message})
        response = requests.post(chat_url, headers=headers, data=data)
        return response.json()

    def bots(self):
        if not self.token:
            raise ValueError("لطفا ابتدا لاگین کنید")
        
        history_url = f"{self.base_url}:81/api/account/bot"
        headers = {'Authorization': f"Bearer {self.token}"}
        response = requests.get(history_url, headers=headers)
        return response.json()




from Hamhoush import ApiClient

api_client = ApiClient()
api_client.login("Hamhoush1@gmail.com", "Hamhoush@123")
response = api_client.chat(bot_id="65df0ebe2891bf64b970ceca",message="سلام")
print("Chat response:", response)

history = api_client.bots()
print("Chat history:", history)


from setuptools import setup

setup(
    # Needed to silence warnings (and to be a worthwhile package)
    name='HamhoushSDK',
    author='Smilinno',
    packages=['Hamhoush'],
    # Needed for dependencies
    install_requires=['numpy','requests'],
    # *strongly* suggested for sharing
    version='0.1',
    description='hamhoush platform sdk',
)